soilindex(x, index, returnHCR = "auto", weighted = TRUE, ...)SpeclibFALSE the reflectance values of nearest neighbour to passed position are returned. See If function is called without any arguments, return value will be a vector containing all available indices in alphabetical order.
* For references please type: hsdardocs("References.pdf").
** TM_1 denotes the first band of Landsat Thematic Mapper. Consequently, the hyperspectral data is resmapled to Landsat TM using spectralResampling prior to the calculation of the index. For resampling, the spectral response function is used.
}
hsdardocs("References.pdf")vegindex, get_reflectancedata(spectral_data)
## Example calculating all available indices
## Get available indices
avl <- soilindex()
vi <- soilindex(spectral_data, avl)Run the code above in your browser using DataLab