transformSpeclib(data, ..., method = "ch", out = "bd")method != "raw" an object of class Speclib containing transformed spectra is returned. Otherwise the return object will be of class Clman.deletecpSpecify method = "ch" for the convex hull and method = "sh" for the segmented hull.
The output might be "raw", "bd" or "ratio":
Mutanga, O. and Skidmore, A. K. (2004): Hyperspectral band depth analysis for a better estimation of grass biomass (Cenchrus ciliaris) measured under controlled laboratory conditions International Journal of applied Earth Observation and Geoinformation, 5, 87-96.
Clman, addcp, deletecp, checkhulldata(spectral_data)
transformed_spectra <- transformSpeclib(spectral_data)
par(mfrow=c(1,2))
plot(spectral_data)
plot(transformed_spectra)Run the code above in your browser using DataLab